@@ -1,7 +1,6 @@
+import functools
 import os
 import re
-from functools import partial
-from pathlib import Path
 from typing import Optional, Tuple
 from urllib.parse import urlparse, urlunparse
 
@@ -96,51 +95,50 @@ def transform_p_by_p_skipping_codeblocks(markdown, func):
     Skip indented and fenced codeblock lines, where the transformation never is
     applied.
     '''
-    _inside_fcodeblock = False            # inside fenced codeblock
     _current_fcodeblock_delimiter = None  # current fenced codeblock delimiter
     _inside_icodeblock = False            # inside indented codeblock
 
     lines, current_paragraph = ([], '')
 
-    def process_current_paragraph_lines():
+    def process_current_paragraph():
         lines.extend(func(current_paragraph).splitlines(keepends=True))
 
     for line in markdown.splitlines(keepends=True):
-        if not _inside_fcodeblock and not _inside_icodeblock:
+        if not _current_fcodeblock_delimiter and not _inside_icodeblock:
             lstripped_line = line.lstrip()
-            if any([
-                lstripped_line.startswith('```'),
-                lstripped_line.startswith('~~~'),
-            ]):
-                _inside_fcodeblock = True
+            if (
+                lstripped_line.startswith('```') or
+                lstripped_line.startswith('~~~')
+            ):
                 _current_fcodeblock_delimiter = lstripped_line[:3]
                 if current_paragraph:
-                    process_current_paragraph_lines()
+                    process_current_paragraph()
                     current_paragraph = ''
                 lines.append(line)
             elif (
                 # 5 and 2 including newline character
+                #
+                # TODO: Windows endlines has the same length?
                 (line.startswith('    ') and len(line) == 5) or
                 (line.startswith('\t') and len(line) == 2)
             ):
                 _inside_icodeblock = True
-                lines.append(line)
                 if current_paragraph:
-                    process_current_paragraph_lines()
+                    process_current_paragraph()
                     current_paragraph = ''
+                lines.append(line)
             else:
                 current_paragraph += line
         else:
             lines.append(line)
             if _current_fcodeblock_delimiter:
                 if line.lstrip().startswith(_current_fcodeblock_delimiter):
-                    _inside_fcodeblock = False
                     _current_fcodeblock_delimiter = None
             else:
-                if not line.startswith('    '):
+                if not line.startswith('    ') and not line.startswith('\t'):
                     _inside_icodeblock = False
 
-    process_current_paragraph_lines()
+    process_current_paragraph()
 
     return ''.join(lines)
 
@@ -148,46 +146,35 @@ def transform_p_by_p_skipping_codeblocks(markdown, func):
 def transform_line_by_line_skipping_codeblocks(markdown, func):
     '''Apply a transformation line by line in a Markdown text using a function.
 
-    Skip indented and fenced codeblock lines, where the transformation never is
-    applied.
+    Skip fenced codeblock lines, where the transformation never is applied.
+
+    Indented codeblocks are not taken into account because in the practice
+    this function is never used for transformations on indented lines. See
+    the PR https://github.com/mondeja/mkdocs-include-markdown-plugin/pull/95
+    to recover the implementation handling indented codeblocks.
     '''
-    _inside_fcodeblock = False            # inside fenced codeblock
     _current_fcodeblock_delimiter = None  # current fenced codeblock delimiter
-    _inside_icodeblock = False            # inside indented codeblock
 
     lines = []
     for line in markdown.splitlines(keepends=True):
-        if not _inside_fcodeblock and not _inside_icodeblock:
+        if not _current_fcodeblock_delimiter:
             lstripped_line = line.lstrip()
-            if any([
-                lstripped_line.startswith('```'),
-                lstripped_line.startswith('~~~'),
-            ]):
-                _inside_fcodeblock = True
-                _current_fcodeblock_delimiter = line[:3]
-            elif (
-                # 5 and 2 including newline character
-                (line.startswith('    ') and len(line) == 4) or
-                (line.startswith('\t') and len(line) == 1)
+            if (
+                lstripped_line.startswith('```') or
+                lstripped_line.startswith('~~~')
             ):
-                _inside_icodeblock = True
+                _current_fcodeblock_delimiter = lstripped_line[:3]
             else:
                 line = func(line)
-        else:
-            if _current_fcodeblock_delimiter:
-                if line.lstrip().startswith(_current_fcodeblock_delimiter):
-                    _inside_fcodeblock = False
-                    _current_fcodeblock_delimiter = None
-            else:
-                if not line.startswith('    '):
-                    _inside_icodeblock = False
+        elif line.lstrip().startswith(_current_fcodeblock_delimiter):
+            _current_fcodeblock_delimiter = None
         lines.append(line)
 
     return ''.join(lines)
 
 
 def rewrite_relative_urls(
-    markdown: str, source_path: Path, destination_path: Path,
+    markdown: str, source_path: str, destination_path: str,
 ) -> str:
     '''Rewrites markdown so that relative links that were written at
     ``source_path`` will still work when inserted into a file at
@@ -204,12 +191,12 @@ def rewrite_relative_urls(
         trailing_slash = path.endswith('/')
 
         path = os.path.relpath(
-            source_path.parent / path,
-            destination_path.parent,
+            os.path.join(os.path.dirname(source_path), path),
+            os.path.dirname(destination_path),
         )
 
         # ensure forward slashes are used, on Windows
-        path = Path(path).as_posix()
+        path = path.replace('\\', '/').replace('//', '/')
 
         if trailing_slash:
             # the above operation removes a trailing slash. Add it back if it
@@ -229,20 +216,25 @@ def rewrite_relative_urls(
             + m.string[href_end:match_end]
         )
 
+    found_href_url_group_index_3 = functools.partial(
+        found_href,
+        url_group_index=3,
+    )
+
     def transform(paragraph):
         paragraph = re.sub(
             MARKDOWN_LINK_REGEX,
-            partial(found_href, url_group_index=3),
+            found_href_url_group_index_3,
             paragraph,
         )
         paragraph = re.sub(
             MARKDOWN_IMAGE_REGEX,
-            partial(found_href, url_group_index=3),
+            found_href_url_group_index_3,
             paragraph,
         )
         return re.sub(
             MARKDOWN_LINK_DEFINITION_REGEX,
-            partial(found_href, url_group_index=2),
+            functools.partial(found_href, url_group_index=2),
             paragraph,
         )
     return transform_p_by_p_skipping_codeblocks(
@@ -311,22 +303,30 @@ def filter_inclusions(
     return (text_to_include, *expected_not_found)
 
 
+def _transform_negative_offset_func_factory(offset):
+    heading_prefix = '#' * abs(offset)
+    return lambda line: line if not line.startswith('#') else (
+        heading_prefix + line.lstrip('#')
+        if line.startswith(heading_prefix)
+        else '#' + line.lstrip('#')
+    )
+
+
+def _transform_positive_offset_func_factory(offset):
+    heading_prefix = '#' * offset
+    return lambda line: (
+        heading_prefix + line if line.startswith('#') else line
+    )
+
+
 def increase_headings_offset(markdown: str, offset: int = 0):
     '''Increases the headings depth of a snippet of Makdown content.'''
     if not offset:
         return markdown
     return transform_line_by_line_skipping_codeblocks(
         markdown,
-        (
-            lambda line: ('#' * offset + line)
-            if line.startswith('#') else line
-        ) if offset > 0 else (
-            lambda line: line if not line.startswith('#') else (
-                re.sub('^' + '#' * abs(offset), '', line)
-                if line.startswith('#' * abs(offset)) else
-                '#' + line.lstrip('#')
-            )
-        ),
+        _transform_positive_offset_func_factory(offset) if offset > 0
+        else _transform_negative_offset_func_factory(offset),
     )
 
 
